@@ -8,7 +8,7 @@ class RiskAssignmentFilterSet(ChangeLoggedModelFilterSet):
     content_type = ContentTypeFilter()
 
     risk_id = django_filters.ModelMultipleChoiceFilter(
-        queryset=Aduser.objects.all(),
+        queryset=Risk.objects.all(),
         label='Risk (ID)',
     )
 
